@@ -176,9 +176,10 @@ def launch_behavex():
             )
 
         customized_json = get_param('customized_json')
-
+        print("customized_json")
+        print(customized_json)
         if bool(customized_json) is not True and str(customized_json) != 'True':
-            with open(customized_json, 'r') as f:
+            with open("%s\\report_data.json" % os.environ.get('FEATURES_PATH'), 'r') as f:
                 json_reports = json.load(f)
 
         wrap_up_process_pools(process_pool, json_reports, multiprocess, scenario)
